TireCompany class

Constructors

TireCompany({required String manufacturer, required String code, required String city, required String country})

Properties

city String
final
code String
final
country String
final
hashCode int
The hash code for this object.
no setterinherited
manufacturer String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shortName String
Gibt den gekürzten Namen des Herstellers zurück mit nur erstem Buchstaben groß
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited