TireDot class

Constructors

TireDot({required String plantCode, required String sizeCode, String? manufacturingCode, required int weekCode, required int yearCode, required bool isNewCode, TireCompany? company})

Properties

company TireCompany?
final
hashCode int
The hash code for this object.
no setterinherited
isNewCode bool
final
manufacturingCode String?
final
plantCode String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sizeCode String
final
weekCode int
final
yearCode int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited